@@ -18,7 +18,7 @@
 #' biomass_rec <- recipe(HHV ~ ., data = biomass) %>%
 #'    step_rm(sample, dataset) %>%
 #'    check_cols(contains("gen")) %>%
-#'    step_center(all_predictors())
+#'    step_center(all_numeric_predictors())
 #'
 #' \dontrun{
 #' bake(biomass_rec, biomass[, c("carbon", "HHV")])
@@ -56,7 +56,8 @@ check_cols_new <-
   }
 
 prep.check_cols <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- eval_select_recipes(x$terms, training, info)
+
   check_cols_new(
     terms = x$terms,
     role  = x$role,
