@@ -59,7 +59,7 @@
 #'               data = biomass_tr)
 #'
 #' corr_filter <- rec %>%
-#'   step_corr(all_predictors(), threshold = .5)
+#'   step_corr(all_numeric_predictors(), threshold = .5)
 #'
 #' filter_obj <- prep(corr_filter, training = biomass_tr)
 #'
@@ -117,7 +117,7 @@ step_corr_new <-
 
 #' @export
 prep.step_corr <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- eval_select_recipes(x$terms, training, info)
   check_type(training[, col_names])
 
   if (length(col_names) > 1) {
