@@ -52,6 +52,14 @@
 #'   prep() %>%
 #'   bake(df)
 #'
+#' # You can keep the original variables using `step_mutate` or
+#' # `step_mutate_at`, for transforming multiple variables at once
+#' rec %>%
+#'   step_mutate(x_orig = x) %>%
+#'   step_cut(x, breaks = 5) %>%
+#'   prep() %>%
+#'   bake(df)
+#'
 #' # It is up to you if you want values outside the
 #' # range learned at prep to be included
 #' new_df <- data.frame(x = 1:11)
@@ -103,7 +111,8 @@ step_cut_new <-
   }
 
 prep.step_cut <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- eval_select_recipes(x$terms, training, info)
+
   check_type(training[, col_names])
 
   all_breaks <- vector("list", length(col_names))
