@@ -1,6 +1,6 @@
 #' Dummy Variables Creation
 #'
-#' `step_dummy` creates a *specification* of a recipe
+#' `step_dummy()` creates a *specification* of a recipe
 #'  step that will convert nominal data (e.g. character or factors)
 #'  into one or more numeric binary model terms for the levels of
 #'  the original data.
@@ -10,7 +10,7 @@
 #' @param ... One or more selector functions to choose which
 #'  _factor_ variables will be used to create the dummy variables. See
 #'  [selections()] for more details. The selected
-#'  variables must be factors. For the `tidy` method, these are
+#'  variables must be factors. For the `tidy()` method, these are
 #'  not currently used.
 #' @param role For model terms created by this step, what analysis
 #'  role should they be assigned?. By default, the function assumes
@@ -18,14 +18,16 @@
 #'  variables will be used as predictors in a model.
 #' @param one_hot A logical. For C levels, should C dummy variables be created
 #' rather than C-1?
-#' @param preserve A single logical; should the selected column(s) be retained
-#'  (in addition to the new dummy variables).
+#' @param preserve Use `keep_original_cols` to specify whether the selected
+#'  column(s) should be retained (in addition to the new dummy variables).
 #' @param naming A function that defines the naming convention for
 #'  new dummy columns. See Details below.
 #' @param levels A list that contains the information needed to
 #'  create dummy variables for each variable contained in
 #'  `terms`. This is `NULL` until the step is trained by
 #'  [prep.recipe()].
+#' @param keep_original_cols A logical to keep the original variables in the
+#'  output. Defaults to `FALSE`.
 #' @return An updated version of `recipe` with the new step
 #'  added to the sequence of existing steps (if any). For the
 #'  `tidy` method, a tibble with columns `terms` (the
@@ -38,7 +40,7 @@
 #' @concept dummy_variables
 #' @concept variable_encodings
 #' @export
-#' @details `step_dummy` will create a set of binary dummy
+#' @details `step_dummy()` will create a set of binary dummy
 #'  variables from a factor variable. For example, if an unordered
 #'  factor column in the data set has levels of "red", "green",
 #'  "blue", the dummy variable bake will create two additional
@@ -67,7 +69,8 @@
 #' contrast option via `options`.
 #'
 #' When the factor being converted has a missing value, all of the
-#'  corresponding dummy variables are also missing.
+#'  corresponding dummy variables are also missing. See [step_unknown()] for
+#'  a solution.
 #'
 #' When data to be processed contains novel levels (i.e., not
 #' contained in the training set), a missing value is assigned to
@@ -76,6 +79,12 @@
 #' If no columns are selected (perhaps due to an earlier `step_zv()`),
 #'  `bake()` will return the data as-is (e.g. with no dummy variables).
 #'
+#' Note that, by default, the new dummy variable column names obey the naming
+#' rules for columns. If there are levels such as "0", [dummy_names()] will put
+#' a leading "X" in front of the level (since it uses [make.names()]). This can
+#' be changed by passing in a different function to the `naming` argument for
+#' this step.
+#'
 #' The [package vignette for dummy variables](https://recipes.tidymodels.org/articles/Dummies.html)
 #' and interactions has more information.
 #'
@@ -88,31 +97,37 @@
 #' data(okc)
 #' okc <- okc[complete.cases(okc),]
 #'
+#' # Original data: diet has 18 levels
+#' length(unique(okc$diet))
+#' unique(okc$diet) %>% sort()
+#'
 #' rec <- recipe(~ diet + age + height, data = okc)
 #'
-#' dummies <- rec %>% step_dummy(diet)
-#' dummies <- prep(dummies, training = okc)
+#' # Default dummy coding: 17 dummy variables
+#' dummies <- rec %>%
+#'     step_dummy(diet) %>%
+#'     prep(training = okc)
 #'
-#' dummy_data <- bake(dummies, new_data = okc)
+#' dummy_data <- bake(dummies, new_data = NULL)
 #'
-#' unique(okc$diet)
-#' grep("^diet", names(dummy_data), value = TRUE)
+#' dummy_data %>%
+#'     select(starts_with("diet")) %>%
+#'     names() # level "anything" is the reference level
 #'
-#' # Obtain the full set of dummy variables using `one_hot` option
-#' rec %>%
-#'   step_dummy(diet, one_hot = TRUE) %>%
-#'   prep(training = okc) %>%
-#'   bake(new_data = NULL, starts_with("diet")) %>%
-#'   names() %>%
-#'   length()
+#' # Obtain the full set of 18 dummy variables using `one_hot` option
+#' dummies_one_hot <- rec %>%
+#'     step_dummy(diet, one_hot = TRUE) %>%
+#'     prep(training = okc)
 #'
-#' length(unique(okc$diet))
+#' dummy_data_one_hot <- bake(dummies_one_hot, new_data = NULL)
 #'
-#' # Without one_hot
-#' length(grep("^diet", names(dummy_data), value = TRUE))
+#' dummy_data_one_hot %>%
+#'     select(starts_with("diet")) %>%
+#'     names() # no reference level
 #'
 #'
 #' tidy(dummies, number = 1)
+#' tidy(dummies_one_hot, number = 1)
 
 
 step_dummy <-
@@ -121,11 +136,22 @@ step_dummy <-
            role = "predictor",
            trained = FALSE,
            one_hot = FALSE,
-           preserve = FALSE,
+           preserve = deprecated(),
            naming = dummy_names,
            levels = NULL,
+           keep_original_cols = FALSE,
            skip = FALSE,
            id = rand_id("dummy")) {
+
+    if (lifecycle::is_present(preserve)) {
+      lifecycle::deprecate_soft(
+        "0.1.16",
+        "step_dummy(preserve = )",
+        "step_dummy(keep_original_cols = )"
+      )
+      keep_original_cols <- preserve
+    }
+
     add_step(
       recipe,
       step_dummy_new(
@@ -133,9 +159,10 @@ step_dummy <-
         role = role,
         trained = trained,
         one_hot = one_hot,
-        preserve = preserve,
+        preserve = keep_original_cols,
         naming = naming,
         levels = levels,
+        keep_original_cols = keep_original_cols,
         skip = skip,
         id = id
       )
@@ -143,7 +170,8 @@ step_dummy <-
   }
 
 step_dummy_new <-
-  function(terms, role, trained, one_hot, preserve, naming, levels, skip, id) {
+  function(terms, role, trained, one_hot, preserve, naming, levels,
+           keep_original_cols, skip, id) {
     step(
       subclass = "dummy",
       terms = terms,
@@ -153,6 +181,7 @@ step_dummy_new <-
       preserve = preserve,
       naming = naming,
       levels = levels,
+      keep_original_cols = keep_original_cols,
       skip = skip,
       id = id
     )
@@ -165,7 +194,7 @@ passover <- function(cmd) {
 
 #' @export
 prep.step_dummy <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info, empty_fun = passover)
+  col_names <- eval_select_recipes(x$terms, training, info)
 
   if (length(col_names) > 0) {
     fac_check <- vapply(training[, col_names], is.factor, logical(1))
@@ -226,18 +255,20 @@ prep.step_dummy <- function(x, training, info = NULL, ...) {
     preserve = x$preserve,
     naming = x$naming,
     levels = levels,
+    keep_original_cols = get_keep_original_cols(x),
     skip = x$skip,
     id = x$id
   )
 }
 
-warn_new_levels <- function(dat, lvl) {
+warn_new_levels <- function(dat, lvl, details = NULL) {
   ind <- which(!(dat %in% lvl))
   if (length(ind) > 0) {
     lvl2 <- unique(dat[ind])
     rlang::warn(
       paste0("There are new levels in a factor: ",
-            paste0(lvl2, collapse = ", ")
+            paste0(lvl2, collapse = ", "),
+            details
             )
       )
   }
@@ -253,6 +284,7 @@ bake.step_dummy <- function(object, new_data, ...) {
   }
 
   col_names <- names(object$levels)
+  keep_original_cols <- get_keep_original_cols(object)
 
   ## `na.action` cannot be passed to `model.matrix` but we
   ## can change it globally for a bit
@@ -271,7 +303,8 @@ bake.step_dummy <- function(object, new_data, ...) {
 
     if (length(attr(object$levels[[i]], "values")) == 1)
       rlang::abort(
-        paste0("Only one factor level in ", orig_var)
+        paste0("Only one factor level in ", orig_var, ": ",
+               attr(object$levels[[i]], "values"))
         )
 
     warn_new_levels(
@@ -310,7 +343,7 @@ bake.step_dummy <- function(object, new_data, ...) {
     used_lvl <- gsub(paste0("^", col_names[i]), "", colnames(indicators))
     colnames(indicators) <- object$naming(col_names[i], used_lvl, fac_type == "ordered")
     new_data <- bind_cols(new_data, as_tibble(indicators))
-    if (!object$preserve) {
+    if (any(!object$preserve, !keep_original_cols)) {
       new_data[, col_names[i]] <- NULL
     }
   }
@@ -340,8 +373,10 @@ print.step_dummy <-
   }
 
 
-get_dummy_columns <- function(x) {
-  tibble(columns = attr(x, "values"))
+get_dummy_columns <- function(x, one_hot) {
+  x <- attr(x, "values")
+  if (!one_hot) x <- x[-1]
+  tibble(columns = x)
 }
 
 
@@ -351,7 +386,7 @@ get_dummy_columns <- function(x) {
 tidy.step_dummy <- function(x, ...) {
   if (is_trained(x)) {
     if (length(x$levels) > 0) {
-      res <- purrr::map_dfr(x$levels, get_dummy_columns, .id = "terms")
+      res <- purrr::map_dfr(x$levels, get_dummy_columns, x$one_hot, .id = "terms")
     } else {
       res <- tibble(terms = rlang::na_chr, columns = rlang::na_chr)
     }
