@@ -21,7 +21,8 @@
 #'  `tidy` method, a tibble with columns `terms` (the
 #'  columns that will be affected), `inverse`, and `func`.
 #' @keywords datagen
-#' @concept preprocessing transformation_methods
+#' @concept preprocessing
+#' @concept transformation_methods
 #' @export
 #' @examples
 #' set.seed(313)
@@ -31,7 +32,7 @@
 #' rec <- recipe(~ V1 + V2, data = examples)
 #'
 #' cos_trans <- rec  %>%
-#'   step_hyperbolic(all_predictors(),
+#'   step_hyperbolic(all_numeric_predictors(),
 #'                   func = "cos", inverse = FALSE)
 #'
 #' cos_obj <- prep(cos_trans, training = examples)
@@ -57,8 +58,7 @@ step_hyperbolic <-
            id = rand_id("hyperbolic")) {
     funcs <- c("sin", "cos", "tan")
     if (!(func %in% funcs))
-      stop("`func` should be either `sin``, `cos`, or `tan`",
-           call. = FALSE)
+      rlang::abort("`func` should be either `sin``, `cos`, or `tan`")
     add_step(
       recipe,
       step_hyperbolic_new(
@@ -91,7 +91,7 @@ step_hyperbolic_new <-
 
 #' @export
 prep.step_hyperbolic <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- eval_select_recipes(x$terms, training, info)
   check_type(training[, col_names])
 
   step_hyperbolic_new(
