@@ -30,7 +30,7 @@
 #' rec <- recipe(~ X1 + X2, data = examples)
 #'
 #' inverse_trans <- rec  %>%
-#'   step_inverse(all_predictors())
+#'   step_inverse(all_numeric_predictors())
 #'
 #' inverse_obj <- prep(inverse_trans, training = examples)
 #'
@@ -80,7 +80,8 @@ step_inverse_new <-
 
 #' @export
 prep.step_inverse <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- eval_select_recipes(x$terms, training, info)
+
   check_type(training[, col_names])
 
   step_inverse_new(
