@@ -24,6 +24,8 @@
 #'  [prep.recipe()].
 #' @param prefix A character string that will be the prefix to the
 #'  resulting new variables. See notes below.
+#' @param keep_original_cols A logical to keep the original variables in the
+#'  output. Defaults to `FALSE`.
 #' @return An updated version of `recipe` with the new step
 #'  added to the sequence of existing steps (if any). For the
 #'  `tidy` method, a tibble with columns `terms` (the
@@ -80,9 +82,9 @@
 #'               data = biomass_tr)
 #'
 #' kpca_trans <- rec %>%
-#'   step_YeoJohnson(all_predictors()) %>%
-#'   step_normalize(all_predictors()) %>%
-#'   step_kpca_rbf(all_predictors())
+#'   step_YeoJohnson(all_numeric_predictors()) %>%
+#'   step_normalize(all_numeric_predictors()) %>%
+#'   step_kpca_rbf(all_numeric_predictors())
 #'
 #' if (require(dimRed) & require(kernlab)) {
 #'   kpca_estimates <- prep(kpca_trans, training = biomass_tr)
@@ -109,6 +111,7 @@ step_kpca_rbf <-
            res = NULL,
            sigma = 0.2,
            prefix = "kPC",
+           keep_original_cols = FALSE,
            skip = FALSE,
            id = rand_id("kpca_rbf")) {
 
@@ -124,6 +127,7 @@ step_kpca_rbf <-
         res = res,
         sigma = sigma,
         prefix = prefix,
+        keep_original_cols = keep_original_cols,
         skip = skip,
         id = id
       )
@@ -131,7 +135,8 @@ step_kpca_rbf <-
   }
 
 step_kpca_rbf_new <-
-  function(terms, role, trained, num_comp, res, sigma, prefix, skip, id) {
+  function(terms, role, trained, num_comp, res, sigma, prefix,
+           keep_original_cols, skip, id) {
     step(
       subclass = "kpca_rbf",
       terms = terms,
@@ -141,6 +146,7 @@ step_kpca_rbf_new <-
       res = res,
       sigma = sigma,
       prefix = prefix,
+      keep_original_cols = keep_original_cols,
       skip = skip,
       id = id
     )
@@ -148,7 +154,7 @@ step_kpca_rbf_new <-
 
 #' @export
 prep.step_kpca_rbf <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- eval_select_recipes(x$terms, training, info)
   check_type(training[, col_names])
 
   if (x$num_comp > 0) {
@@ -185,6 +191,7 @@ prep.step_kpca_rbf <- function(x, training, info = NULL, ...) {
     sigma = x$sigma,
     res = kprc,
     prefix = x$prefix,
+    keep_original_cols = get_keep_original_cols(x),
     skip = x$skip,
     id = x$id
   )
@@ -200,7 +207,11 @@ bake.step_kpca_rbf <- function(object, new_data, ...) {
     comps <- comps[, 1:object$num_comp, drop = FALSE]
     comps <- check_name(comps, new_data, object)
     new_data <- bind_cols(new_data, as_tibble(comps))
-    new_data <- new_data[, !(colnames(new_data) %in% pca_vars), drop = FALSE]
+    keep_original_cols <- get_keep_original_cols(object)
+
+    if (!keep_original_cols) {
+      new_data <- new_data[, !(colnames(new_data) %in% pca_vars), drop = FALSE]
+    }
   }
   as_tibble(new_data)
 }
@@ -230,7 +241,7 @@ tidy.step_kpca_rbf <- function(x, ...) {
     if (x$num_comp > 0) {
       res <- tibble(terms = colnames(x$res@org.data))
     } else {
-      res <- tibble(terms = x$res$x_vars)
+      res <- tibble(terms = unname(x$res$x_vars))
     }
   } else {
     term_names <- sel2char(x$terms)
