@@ -46,7 +46,7 @@
 #'               data = biomass_tr)
 #'
 #' lincomb_filter <- rec %>%
-#'   step_lincomb(all_predictors())
+#'   step_lincomb(all_numeric_predictors())
 #'
 #' lincomb_filter_trained <- prep(lincomb_filter, training = biomass_tr)
 #' lincomb_filter_trained
@@ -96,7 +96,8 @@ step_lincomb_new <-
 
 #' @export
 prep.step_lincomb <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- eval_select_recipes(x$terms, training, info)
+
   check_type(training[, col_names])
 
   filter <- iter_lc_rm(x = training[, col_names],
