@@ -34,7 +34,7 @@
 #' rec <- recipe(~ V1 + V2, data = examples)
 #'
 #' log_trans <- rec  %>%
-#'   step_log(all_predictors())
+#'   step_log(all_numeric_predictors())
 #'
 #' log_obj <- prep(log_trans, training = examples)
 #'
@@ -50,12 +50,12 @@
 #' examples2 <- as.data.frame(examples2)
 #'
 #' recipe(~ V1 + V2, data = examples2) %>%
-#'   step_log(all_predictors()) %>%
+#'   step_log(all_numeric_predictors()) %>%
 #'   prep(training = examples2) %>%
 #'   bake(examples2)
 #'
 #' recipe(~ V1 + V2, data = examples2) %>%
-#'   step_log(all_predictors(), signed = TRUE) %>%
+#'   step_log(all_numeric_predictors(), signed = TRUE) %>%
 #'   prep(training = examples2) %>%
 #'   bake(examples2)
 #'
@@ -110,7 +110,8 @@ step_log_new <-
 
 #' @export
 prep.step_log <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- eval_select_recipes(x$terms, training, info)
+
   check_type(training[, col_names])
 
   step_log_new(
