@@ -61,7 +61,7 @@ get_rhs_vars <- function(formula, data, no_lhs = FALSE) {
   ## or embedded functions like `Sepal.Length + poly(Sepal.Width)`.
   ## or should it? what about Y ~ log(x)?
   ## Answer: when called from `form2args`, the function
-  ## `element_check` stops when in-line functions are used.
+  ## `inline_check` stops when in-line functions are used.
   data_info <- attr(model.frame(formula, data), "terms")
   response_info <- attr(data_info, "response")
   predictor_names <- names(attr(data_info, "dataClasses"))
@@ -307,7 +307,7 @@ ellipse_check <- function(...) {
 #'  recipe (e.g. `terms` in most steps).
 #' @param trained A logical for whether the step has been trained.
 #' @param width An integer denoting where the output should be wrapped.
-#' @return `NULL``, invisibly.
+#' @return `NULL`, invisibly.
 #' @keywords internal
 #' @export
 #' @rdname recipes-internal
@@ -333,7 +333,7 @@ printer <- function(tr_obj = NULL,
 #' @export
 #' @keywords internal
 #' @rdname recipes-internal
-prepare   <- function(x, ...)
+prepare <- function(x, ...)
   rlang::abort(paste0("As of version 0.0.1.9006, used `prep` ",
        "instead of `prepare`"))
 
@@ -343,20 +343,28 @@ prepare   <- function(x, ...)
 #' @param x A recipe
 #' @return A logical which is true if all of the recipe steps have been run
 #'  through `prep`. If no steps have been added to the recipe, `TRUE` is
-#'  returned.
+#'  returned only if the recipe has been prepped.
 #' @export
 #' @examples
 #' rec <- recipe(Species ~ ., data = iris) %>%
 #'   step_center(all_numeric())
 #'
-#' rec %>% fully_trained
+#' rec %>% fully_trained()
 #'
-#' rec %>% prep(training = iris) %>% fully_trained
+#'
+#' rec %>% prep(training = iris) %>% fully_trained()
 fully_trained <- function(x) {
-  if (is.null(x$steps))
-    return(TRUE)
-  is_tr <- vapply(x$steps, function(x) isTRUE(x$trained), logical(1))
-  all(is_tr)
+  if (is.null(x$steps)) {
+    if (any(names(x) == "last_term_info")) {
+      res <- TRUE
+    } else {
+      res <- FALSE
+    }
+  } else {
+    is_tr <- purrr::map_lgl(x$steps, function(x) isTRUE(x$trained))
+    res <- all(is_tr)
+  }
+  res
 }
 
 #' Detect if a particular step or check is used in a recipe
@@ -466,7 +474,7 @@ to_character <- function(x) {
 
 simple_terms <- function(x, ...) {
   if (is_trained(x)) {
-    res <- tibble(terms = x$columns)
+    res <- tibble(terms = unname(x$columns))
   } else {
     term_names <- sel2char(x$terms)
     res <- tibble(terms = term_names)
@@ -628,6 +636,32 @@ check_training_set <- function(x, rec, fresh) {
   x
 }
 
+#' Get the `keep_original_cols` value of a recipe step
+#'
+#' @export
+#' @param object A recipe step
+#' @return A logical to keep the original variables in the output
+#' @keywords internal
+get_keep_original_cols <- function(object) {
+  # Allow prepping of old recipes created before addition of keep_original_cols
+  step_class <- class(object)[1]
+
+  if (is.null(object$keep_original_cols)) {
+    ret <- FALSE
+    rlang::warn(
+      paste0(
+        "'keep_original_cols' was added to `",
+        step_class,
+        "()` after this recipe was created.\n",
+        "Regenerate your recipe to avoid this warning."
+      )
+    )
+  } else {
+    ret <- object$keep_original_cols
+  }
+
+  ret
+}
 
 # ------------------------------------------------------------------------------
 # From parsnip, keep synced
