@@ -33,6 +33,7 @@
 #'  `prep.recipe`. `bake.recipe` then applies the scaling to new data sets using
 #'  these estimates.
 #' @examples
+#' library(modeldata)
 #' data(biomass)
 #'
 #' biomass_tr <- biomass[biomass$dataset == "Training",]
@@ -53,6 +54,15 @@
 #' tidy(norm_trans, number = 1)
 #' tidy(norm_obj, number = 1)
 #'
+#' # To keep the original variables in the output, use `step_mutate_at`:
+#' norm_keep_orig <- rec %>%
+#'   step_mutate_at(all_numeric_predictors(), fn = list(orig = ~.)) %>%
+#'   step_normalize(-contains("orig"), -all_outcomes())
+#'
+#' keep_orig_obj <- prep(norm_keep_orig, training = biomass_tr)
+#' keep_orig_te <- bake(keep_orig_obj, biomass_te)
+#' keep_orig_te
+#'
 step_normalize <-
   function(recipe,
            ...,
@@ -95,7 +105,8 @@ step_normalize_new <-
 
 #' @export
 prep.step_normalize <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- eval_select_recipes(x$terms, training, info)
+
   check_type(training[, col_names])
 
   means <- vapply(training[, col_names], mean, c(mean = 0), na.rm = x$na_rm)
@@ -116,8 +127,7 @@ prep.step_normalize <- function(x, training, info = NULL, ...) {
 bake.step_normalize <- function(object, new_data, ...) {
   res <- sweep(as.matrix(new_data[, names(object$means)]), 2, object$means, "-")
   res <- sweep(res, 2, object$sds, "/")
-  if (is.matrix(res) && ncol(res) == 1)
-    res <- res[, 1]
+  res <- tibble::as_tibble(res)
   new_data[, names(object$sds)] <- res
   as_tibble(new_data)
 }
