@@ -39,6 +39,11 @@
 #' If `new_level` is already in the data given to `prep`, an error
 #'  is thrown.
 #'
+#' When fitting a model that can deal with new factor levels, consider using
+#'  [workflows::add_recipe()] with `allow_novel_levels = TRUE` set in
+#'  [hardhat::default_recipe_blueprint()]. This will allow your model to handle
+#'  new levels at prediction time, instead of throwing warnings or errors.
+#'
 #' @seealso [step_factor2string()], [step_string2factor()],
 #'  [dummy_names()], [step_regex()], [step_count()],
 #'  [step_ordinalscore()], [step_unorder()], [step_other()]
@@ -116,8 +121,10 @@ get_existing_values <- function(x) {
 
 #' @export
 prep.step_novel <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- eval_select_recipes(x$terms, training, info)
+
   col_check <- dplyr::filter(info, variable %in% col_names)
+
   if (any(col_check$type != "nominal"))
     rlang::abort(
       paste0("Columns must be character or factor: ",
