@@ -17,8 +17,8 @@
 #'  possible dimensions, a smaller value will be used.
 #' @param predictor_prop The maximum number of original predictors that can have
 #'  non-zero coefficients for each PLS component (via regularization).
-#' @param preserve A single logical: should the original predictor data be
-#' retained along with the new features?
+#' @param preserve Use `keep_original_cols` instead to specify whether the
+#'  original predictor data should be retained along with the new features.
 #' @param outcome When a single outcome is available, character
 #'  string or call to [dplyr::vars()] can be used to specify a single outcome
 #'  variable.
@@ -29,6 +29,8 @@
 #'  has been trained by [prep.recipe()].
 #' @param prefix A character string that will be the prefix to the
 #'  resulting new variables. See notes below.
+#' @param keep_original_cols A logical to keep the original variables in the
+#'  output. Defaults to `FALSE`.
 #' @return An updated version of `recipe` with the new step
 #'  added to the sequence of existing steps (if any). For the
 #'  `tidy` method, a tibble with columns `terms` (the
@@ -74,7 +76,7 @@
 #'
 #' Rohart F, Gautier B, Singh A, Lê Cao K-A (2017) _mixOmics: An R package for
 #' 'omics feature selection and multiple data integration_. PLoS Comput Biol
-#' 13(11): e1005752. \url{https://doi.org/10.1371/journal.pcbi.1005752}
+#' 13(11): e1005752. \doi{10.1371/journal.pcbi.1005752}
 #' @examples
 #' # requires the Bioconductor mixOmics package
 #' data(biomass, package = "modeldata")
@@ -90,11 +92,11 @@
 #'
 #' dense_pls <-
 #'   recipe(HHV ~ ., data = biom_tr) %>%
-#'   step_pls(all_predictors(), outcome = "HHV", num_comp = 3)
+#'   step_pls(all_numeric_predictors(), outcome = "HHV", num_comp = 3)
 #'
 #' sparse_pls <-
 #'   recipe(HHV ~ ., data = biom_tr) %>%
-#'   step_pls(all_predictors(), outcome = "HHV", num_comp = 3, predictor_prop = 4/5)
+#'   step_pls(all_numeric_predictors(), outcome = "HHV", num_comp = 3, predictor_prop = 4/5)
 #'
 #' ## -----------------------------------------------------------------------------
 #' ## PLS discriminant analysis
@@ -112,11 +114,11 @@
 #'
 #' dense_plsda <-
 #'   recipe(class ~ ., data = cell_tr) %>%
-#'   step_pls(all_predictors(), outcome = "class", num_comp = 5)
+#'   step_pls(all_numeric_predictors(), outcome = "class", num_comp = 5)
 #'
 #' sparse_plsda <-
 #'   recipe(class ~ ., data = cell_tr) %>%
-#'   step_pls(all_predictors(), outcome = "class", num_comp = 5, predictor_prop = 1/4)
+#'   step_pls(all_numeric_predictors(), outcome = "class", num_comp = 5, predictor_prop = 1/4)
 #'
 #' @seealso [step_pca()], [step_kpca()], [step_ica()], [recipe()],
 #'  [prep.recipe()], [bake.recipe()]
@@ -130,15 +132,25 @@ step_pls <-
            predictor_prop = 1,
            outcome = NULL,
            options = list(scale = TRUE),
-           preserve = FALSE,
+           preserve = deprecated(),
            res = NULL,
            prefix = "PLS",
+           keep_original_cols = FALSE,
            skip = FALSE,
            id = rand_id("pls")) {
     if (is.null(outcome)) {
       rlang::abort("`outcome` should select at least one column.")
     }
 
+    if (lifecycle::is_present(preserve)) {
+      lifecycle::deprecate_soft(
+        "0.1.16",
+        "step_pls(preserve = )",
+        "step_pls(keep_original_cols = )"
+      )
+      keep_original_cols <- preserve
+    }
+
     recipes_pkg_check(required_pkgs.step_pls())
 
     add_step(
@@ -151,9 +163,10 @@ step_pls <-
         predictor_prop = predictor_prop,
         outcome = outcome,
         options = options,
-        preserve = preserve,
+        preserve = keep_original_cols,
         res = res,
         prefix = prefix,
+        keep_original_cols = keep_original_cols,
         skip = skip,
         id = id
       )
@@ -162,7 +175,7 @@ step_pls <-
 
 step_pls_new <-
   function(terms, role, trained, num_comp, predictor_prop, outcome, options,
-           preserve, res, prefix, skip, id) {
+           preserve, res, prefix, keep_original_cols, skip, id) {
     step(
       subclass = "pls",
       terms = terms,
@@ -175,6 +188,7 @@ step_pls_new <-
       preserve = preserve,
       res = res,
       prefix = prefix,
+      keep_original_cols = keep_original_cols,
       skip = skip,
       id = id
     )
@@ -295,8 +309,9 @@ prop2int <- function(x, p) {
 
 #' @export
 prep.step_pls <- function(x, training, info = NULL, ...) {
-  x_names <- terms_select(x$terms,   info = info)
-  y_names <- terms_select(x$outcome, info = info)
+  x_names <- eval_select_recipes(x$terms, training, info)
+  y_names <- eval_select_recipes(x$outcome, training, info)
+
   check_type(training[, x_names])
   if (length(y_names) > 1 ) {
     rlang::abort("`step_pls()` only supports univariate models.")
@@ -333,6 +348,7 @@ prep.step_pls <- function(x, training, info = NULL, ...) {
     preserve = x$preserve,
     res = res,
     prefix = x$prefix,
+    keep_original_cols = get_keep_original_cols(x),
     skip = x$skip,
     id = x$id
   )
@@ -352,10 +368,20 @@ bake.step_pls <- function(object, new_data, ...) {
     comps <- check_name(comps, new_data, object)
 
     new_data <- bind_cols(new_data, as_tibble(comps))
-    if (!use_old_pls(object$res) && !object$preserve) {
+    keep_original_cols <- get_keep_original_cols(object)
+
+    # Old pls never preserved original columns,
+    # but didn't have the `preserve` option
+    if (use_old_pls(object$res)) {
+      pls_vars <- rownames(object$res$projection)
+      keep_vars <- !(colnames(new_data) %in% pls_vars)
+      new_data <- new_data[, keep_vars, drop = FALSE]
+    } else if (any(!object$preserve, !keep_original_cols)) {
       pls_vars <- names(object$res$mu)
-      new_data <- new_data[, !(colnames(new_data) %in% pls_vars), drop = FALSE]
+      keep_vars <- !(colnames(new_data) %in% pls_vars)
+      new_data <- new_data[, keep_vars, drop = FALSE]
     }
+
     if (!is_tibble(new_data)) {
       new_data <- as_tibble(new_data)
     }
