@@ -27,6 +27,8 @@
 #' @param columns The column names used in the ratios. This
 #'  argument is not populated until [prep.recipe()] is
 #'  executed.
+#' @param keep_original_cols A logical to keep the original variables in the
+#'  output. Defaults to `TRUE`.
 #' @return An updated version of `recipe` with the new step
 #'  added to the sequence of existing steps (if any). For the
 #'  `tidy` method, a tibble with columns `terms` (the
@@ -49,7 +51,7 @@
 #'
 #' ratio_recipe <- rec %>%
 #'   # all predictors over total
-#'   step_ratio(all_predictors(), denom = denom_vars(total)) %>%
+#'   step_ratio(all_numeric_predictors(), denom = denom_vars(total)) %>%
 #'   # get rid of the original predictors
 #'   step_rm(all_predictors(), -ends_with("total"))
 #'
@@ -67,6 +69,7 @@ step_ratio <-
            naming = function(numer, denom)
              make.names(paste(numer, denom, sep = "_o_")),
            columns = NULL,
+           keep_original_cols = TRUE,
            skip = FALSE,
            id = rand_id("ratio")) {
     if (is_empty(denom))
@@ -85,6 +88,7 @@ step_ratio <-
         denom = denom,
         naming = naming,
         columns = columns,
+        keep_original_cols = keep_original_cols,
         skip = skip,
         id = id
       )
@@ -92,7 +96,8 @@ step_ratio <-
   }
 
 step_ratio_new <-
-  function(terms, role, trained, denom, naming, columns, skip, id) {
+  function(terms, role, trained, denom, naming, columns,
+           keep_original_cols, skip, id) {
     step(
       subclass = "ratio",
       terms = terms,
@@ -101,6 +106,7 @@ step_ratio_new <-
       denom = denom,
       naming = naming,
       columns = columns,
+      keep_original_cols = keep_original_cols,
       skip = skip,
       id = id
     )
@@ -110,8 +116,8 @@ step_ratio_new <-
 #' @export
 prep.step_ratio <- function(x, training, info = NULL, ...) {
   col_names <- expand.grid(
-    top = terms_select(x$terms, info = info),
-    bottom = terms_select(x$denom, info = info),
+    top = eval_select_recipes(x$terms, training, info),
+    bottom = eval_select_recipes(x$denom, training, info),
     stringsAsFactors = FALSE
   )
   col_names <- col_names[!(col_names$top == col_names$bottom), ]
@@ -130,6 +136,7 @@ prep.step_ratio <- function(x, training, info = NULL, ...) {
     denom = x$denom,
     naming = x$naming,
     columns = col_names,
+    keep_original_cols = get_keep_original_cols(x),
     skip = x$skip,
     id = x$id
   )
@@ -145,7 +152,14 @@ bake.step_ratio <- function(object, new_data, ...) {
   if (!is_tibble(res))
     res <- as_tibble(res)
 
+  keep_original_cols <- get_keep_original_cols(object)
   new_data <- bind_cols(new_data, res)
+
+  if (!keep_original_cols) {
+    union_cols <- union(object$columns$top, object$columns$bottom)
+    new_data <- new_data[, !(colnames(new_data) %in% union_cols), drop = FALSE]
+  }
+
   if (!is_tibble(new_data))
     new_data <- as_tibble(new_data)
   new_data
@@ -175,8 +189,8 @@ denom_vars <- function(...) quos(...)
 #' @export
 tidy.step_ratio <- function(x, ...) {
   if (is_trained(x)) {
-    res <- tibble(terms = x$columns$top,
-                  denom = x$columns$bottom)
+    res <- tibble(terms = unname(x$columns$top),
+                  denom = unname(x$columns$bottom))
   } else {
     res <- tidyr::crossing(terms = sel2char(x$terms),
                            denom = sel2char(x$denom))
