@@ -1,7 +1,7 @@
-#' Rename multiple columns
+#' Rename multiple columns using dplyr
 #'
 #' `step_rename_at` creates a *specification* of a recipe step that will rename
-#' the selected variables using a common function.
+#' the selected variables using a common function via [dplyr::rename_at()].
 #'
 #' @inheritParams step_center
 #' @param fn A function `fun`, a quosure style lambda `~ fun(.)`` or a list of
@@ -67,7 +67,8 @@ step_rename_at_new <-
 
 #' @export
 prep.step_rename_at <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- eval_select_recipes(x$terms, training, info)
+
   step_rename_at_new(
     terms = x$terms,
     fn = x$fn,
