@@ -30,7 +30,7 @@
 #' rec <- recipe(~ V1 + V2, data = examples)
 #'
 #' sqrt_trans <- rec  %>%
-#'   step_sqrt(all_predictors())
+#'   step_sqrt(all_numeric_predictors())
 #'
 #' sqrt_obj <- prep(sqrt_trans, training = examples)
 #'
@@ -76,7 +76,7 @@ step_sqrt_new <-
 
 #' @export
 prep.step_sqrt <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- eval_select_recipes(x$terms, training, info)
   check_type(training[, col_names])
 
   step_sqrt_new(
