@@ -31,7 +31,7 @@
 #' rec <- recipe(~ X1 + X2, data = examples)
 #'
 #' factor_trans <- rec  %>%
-#'   step_unorder(all_predictors())
+#'   step_unorder(all_nominal_predictors())
 #'
 #' factor_obj <- prep(factor_trans, training = examples)
 #'
@@ -77,7 +77,7 @@ step_unorder_new <-
 
 #' @export
 prep.step_unorder <- function(x, training, info = NULL, ...) {
-  col_names <- terms_select(x$terms, info = info)
+  col_names <- eval_select_recipes(x$terms, training, info)
   order_check <- vapply(training[, col_names],
                         is.ordered,
                         logical(1L))
