@@ -5,7 +5,8 @@ library(recipes)
 
 context("bagged imputation")
 
-data("biomass")
+library(modeldata)
+data(biomass)
 
 biomass$fac <- factor(sample(letters[1:2], size = nrow(biomass), replace = TRUE))
 
@@ -55,7 +56,7 @@ test_that('imputation models', {
            model = imputed_trained$steps[[1]]$models,
            id = imputed_trained$steps[[1]]$id)
 
-  expect_equal(tidy(imputed, 1), imp_tibble_un)
+  expect_equivalent(as.data.frame(tidy(imputed, 1)), as.data.frame(imp_tibble_un))
   expect_equal(tidy(imputed_trained, 1)$terms, imp_tibble_tr$terms)
   expect_equal(tidy(imputed_trained, 1)$model, imp_tibble_tr$model)
 
@@ -76,7 +77,7 @@ test_that('tunable', {
   rec <-
     recipe(~ ., data = iris) %>%
     step_bagimpute(all_predictors(), impute_with = imp_vars(all_predictors()))
-  rec_param <- tunable.step_bagimpute(rec$steps[[1]])
+  rec_param <- tunable.step_impute_bag(rec$steps[[1]])
   expect_equal(rec_param$name, c("trees"))
   expect_true(all(rec_param$source == "recipe"))
   expect_true(is.list(rec_param$call_info))
