@@ -6,6 +6,8 @@ context("Testing basic functionalities")
 
 library(modeldata)
 data(biomass)
+biomass_tr <- biomass[biomass$dataset == "Training",]
+biomass_te <- biomass[biomass$dataset == "Testing",]
 
 test_that("Recipe correctly identifies output variable", {
   raw_recipe <- recipe(HHV ~ ., data = biomass)
@@ -105,11 +107,11 @@ test_that("bake without prep", {
     step_spatialsign(all_predictors())
   expect_error(
     bake(sp_signed, new_data = biomass_te),
-    "At least one step has not been trained. Please run `prep`."
+    "At least one step has not been trained. Please run."
   )
   expect_error(
     juice(sp_signed),
-    "At least one step has not been trained. Please run `prep`."
+    "At least one step has not been trained. Please run."
   )
 })
 
@@ -143,8 +145,6 @@ test_that("`bake()` returns a 0 column / N row tibble when a selection returns n
   )
 })
 
-
-
 test_that("tunable arguments at prep-time", {
  .tune <- function() rlang::call2("tune")
 
@@ -155,3 +155,50 @@ test_that("tunable arguments at prep-time", {
    "'deg_free'. Do you want "
  )
 })
+
+test_that("logging", {
+
+  expect_output(
+    recipe(mpg ~ ., data = mtcars) %>%
+      step_ns(disp, deg_free = 2, id = "splines!") %>%
+      prep(log_changes = TRUE),
+    "splines"
+  )
+})
+
+test_that("`bake(new_data = NULL)` same as `juice()`", {
+  rec <-
+    recipe(mpg ~ ., data = mtcars) %>%
+    step_filter(gear == 4) %>%
+    step_center(all_predictors()) %>%
+    prep()
+
+  juiced <- juice(rec)
+  baked <- bake(rec, new_data = NULL)
+  expect_equal(juiced, baked)
+
+  # make sure that filter is skipped on training data this way
+  roasted <- bake(rec, new_data = mtcars)
+  expect_equal(nrow(roasted), 32)
+
+})
+
+test_that("`retain flag in prep should return data when TRUE and zero rows when FALSE", {
+  rec <-  recipe(mpg ~ ., data = mtcars %>% head(20))
+
+  # flag TRUE but no training data
+  prec_1 <- prep(rec, retain = TRUE)
+  expect_equal(nrow(prec_1$template), 20)
+
+  #flag FALSE and no training data
+  prec_2 <- prep(rec, retain = FALSE)
+  expect_equal(nrow(prec_2$template), 0)
+
+  #flag TRUE with training data
+  prec_3 <- prep(rec, training = mtcars %>% tail(12),retain = TRUE)
+  expect_equal(nrow(prec_3$template), 12)
+
+  #flag FALSE with training data
+  prec_4 <- prep(rec, training = mtcars %>% tail(12),retain = FALSE)
+  expect_equal(nrow(prec_4$template), 0)
+})
