@@ -4,6 +4,7 @@ library(recipes)
 context("Dummy variable creation")
 
 
+library(modeldata)
 data(okc)
 
 okc_missing <- okc
@@ -45,13 +46,13 @@ test_that('dummy variables with factor inputs', {
       terms = "diet",
       columns = attributes(dummy_trained$steps[[1]]$levels$diet)$values,
       id = ""
-    )
+    ) %>% slice(-1)
   dum_tibble_prepped_2 <-
     tibble(
       terms = "location",
       columns = attributes(dummy_trained$steps[[1]]$levels$location)$values,
       id = ""
-    )
+    ) %>% slice(-1)
   expect_equal(tidy(dummy, 1), dum_tibble)
   expect_equal(
     tidy(dummy_trained, 1),
@@ -83,7 +84,7 @@ test_that('dummy variables with non-factor inputs', {
 
 test_that('create all dummy variables', {
   rec <- recipe(age ~ location + diet + height, data = okc_fac)
-  dummy <- rec %>% step_dummy(diet, location, one_hot = TRUE)
+  dummy <- rec %>% step_dummy(diet, location, one_hot = TRUE, id = "")
   dummy_trained <- prep(dummy, training = okc_fac, verbose = FALSE, strings_as_factors = FALSE)
   dummy_pred <- bake(dummy_trained, new_data = okc_fac, all_predictors())
   dummy_pred <- dummy_pred[, order(colnames(dummy_pred))]
@@ -100,6 +101,26 @@ test_that('create all dummy variables', {
   exp_res <- as.data.frame(exp_res)
   rownames(exp_res) <- NULL
   expect_equivalent(dummy_pred, exp_res)
+
+  dum_tibble <-
+    tibble(terms = c("diet", "location"), columns = rep(rlang::na_chr, 2), id = "")
+  dum_tibble_prepped_1 <-
+    tibble(
+      terms = "diet",
+      columns = attributes(dummy_trained$steps[[1]]$levels$diet)$values,
+      id = ""
+    )
+  dum_tibble_prepped_2 <-
+    tibble(
+      terms = "location",
+      columns = attributes(dummy_trained$steps[[1]]$levels$location)$values,
+      id = ""
+    )
+  expect_equal(
+    tidy(dummy_trained, 1),
+    bind_rows(dum_tibble_prepped_1, dum_tibble_prepped_2)
+  )
+
 })
 
 test_that('tests for issue #91', {
@@ -128,7 +149,7 @@ test_that('tests for NA values in factor', {
   rec <- recipe(~ diet, data = okc_missing)
   factors <- rec %>% step_dummy(diet)
   expect_warning(
-    factors <- prep(factors, training = okc_missing, retain = TRUE)
+    factors <- prep(factors, training = okc_missing)
   )
 
   factors_data_0 <- juice(factors)
@@ -150,7 +171,7 @@ test_that('tests for NA values in ordered factor', {
   rec <- recipe(~ diet, data = okc_ordered)
   factors <- rec %>% step_dummy(diet)
   expect_warning(
-    factors <- prep(factors, training = okc_ordered, retain = TRUE)
+    factors <- prep(factors, training = okc_ordered)
   )
 
   factors_data_0 <- juice(factors)
@@ -191,7 +212,7 @@ test_that('new levels', {
   rec <- recipe(y ~ x1, data = training) %>%
     step_dummy(x1)
   expect_silent(
-    rec <- prep(rec, training = training, retain = TRUE)
+    rec <- prep(rec, training = training)
   )
   expect_warning(
     bake(rec, new_data = testing)
@@ -251,7 +272,7 @@ test_that('no columns selected', {
 
   expect_null(rec$steps[[2]]$levels)
 
-  expect_equal(names(bake(rec, zdat)), c("y", "z"))
+  expect_equal(names(bake(rec, zdat)), c("z", "y"))
 
   expect_output(print(rec), regexp = "since no columns were selected")
 
@@ -269,3 +290,33 @@ test_that('retained columns', {
   expect_true(any(colnames(dummy_pred) == "diet"))
   expect_true(any(colnames(dummy_pred) == "location"))
 })
+
+test_that('keep_original_cols works', {
+  rec <- recipe(age ~ diet, data = okc_fac)
+  dummy <- rec %>% step_dummy(diet, id = "", keep_original_cols = TRUE)
+  dummy_trained <- prep(dummy, training = okc_fac, verbose = FALSE)
+  dummy_pred <- bake(dummy_trained, new_data = okc_fac, all_predictors())
+
+  expect_equal(
+    colnames(dummy_pred),
+    c("diet",
+      paste0("diet_", setdiff(gsub(" ", ".", levels(okc_fac$diet)), "anything")))
+  )
+})
+
+test_that('can prep recipes with no keep_original_cols', {
+  rec <- recipe(age ~ diet, data = okc_fac)
+  dummy <- rec %>% step_dummy(diet, id = "", keep_original_cols = TRUE)
+
+  dummy$steps[[1]]$keep_original_cols <- NULL
+
+  expect_warning(
+    dummy_trained <- prep(dummy, training = okc_fac, verbose = FALSE),
+    "'keep_original_cols' was added to"
+  )
+
+  expect_error(
+    dummy_pred <- bake(dummy_trained, new_data = okc_fac, all_predictors()),
+    NA
+  )
+})
