@@ -1,5 +1,6 @@
 library(testthat)
 library(recipes)
+library(modeldata)
 data(biomass)
 
 context("ICA")
@@ -88,10 +89,11 @@ test_that('correct ICA values', {
   vars <- c("carbon", "hydrogen", "oxygen" ,"nitrogen", "sulfur")
   tidy_exp_un <- tibble(
     terms = rep(vars, 2),
-    value = rep(NA_real_, 2*5),
     component = rep(c("IC1", "IC2"), 5),
+    value = rep(NA_real_, 2*5),
     id = ""
-  )
+  ) %>%
+    arrange(terms, component)
   expect_equal(tidy_exp_un, tidy(ica_extract, number = 1))
 
   loadings <- dimRed::getRotationMatrix(ica_extract_trained$steps[[1]]$res)
@@ -102,11 +104,12 @@ test_that('correct ICA values', {
   loadings <- utils::stack(loadings)
 
   tidy_exp_tr <- tibble(
-    terms = tidy_exp_un$terms,
-    value = loadings$values,
+    terms = rep(vars, 2),
     component = as.character(loadings$ind),
+    value = loadings$values,
     id = ""
-  )
+  ) %>%
+    arrange(terms, component)
   expect_equal(tidy_exp_tr, tidy(ica_extract_trained, number = 1))
 
 })
@@ -151,3 +154,48 @@ test_that('tunable', {
     c('name', 'call_info', 'source', 'component', 'component_id')
   )
 })
+
+test_that('keep_original_cols works', {
+
+  skip_if_not_installed("dimRed")
+  skip_if_not_installed("fastICA")
+  skip_if_not_installed("RSpectra")
+
+  ica_extract <- rec %>%
+    step_ica(carbon, hydrogen, oxygen, nitrogen, sulfur, num_comp = 2,
+             id = "", keep_original_cols = TRUE)
+
+  set.seed(12)
+  ica_extract_trained <- prep(ica_extract, training = biomass_tr, verbose = FALSE)
+
+  ica_pred <- bake(ica_extract_trained, new_data = biomass_te, all_predictors())
+
+
+  expect_equal(
+    colnames(ica_pred),
+    c("carbon", "hydrogen", "oxygen", "nitrogen", "sulfur",
+      "IC1", "IC2")
+  )
+})
+
+test_that('can prep recipes with no keep_original_cols', {
+  skip_if_not_installed("dimRed")
+  skip_if_not_installed("fastICA")
+  skip_if_not_installed("RSpectra")
+
+  ica_extract <- rec %>%
+    step_ica(carbon, hydrogen, oxygen, nitrogen, sulfur, num_comp = 2, id = "")
+
+  ica_extract$steps[[1]]$keep_original_cols <- NULL
+
+  expect_warning(
+    ica_extract_trained <- prep(ica_extract, training = biomass_tr, verbose = FALSE),
+    "'keep_original_cols' was added to"
+  )
+
+  expect_error(
+    ica_pred <- bake(ica_extract_trained, new_data = biomass_te, all_predictors()),
+    NA
+  )
+
+})
