@@ -87,7 +87,7 @@ test_that('tunable', {
   rec <-
     recipe(~ ., data = iris) %>%
     step_meanimpute(all_predictors())
-  rec_param <- tunable.step_meanimpute(rec$steps[[1]])
+  rec_param <- tunable.step_impute_mean(rec$steps[[1]])
   expect_equal(rec_param$name, c("trim"))
   expect_true(all(rec_param$source == "recipe"))
   expect_true(is.list(rec_param$call_info))
