@@ -116,7 +116,7 @@ test_that('tunable', {
   rec <-
     recipe(~ ., data = iris) %>%
     step_rollimpute(all_predictors(), outcome = "Species")
-  rec_param <- tunable.step_rollimpute(rec$steps[[1]])
+  rec_param <- tunable.step_impute_roll(rec$steps[[1]])
   expect_equal(rec_param$name, c("statistic", "window"))
   expect_true(all(rec_param$source == "recipe"))
   expect_true(is.list(rec_param$call_info))
